import { GitIdentity, GithubCredentials } from ".";
import { Job } from "./workflows-model";
/**
 * A set of utility functions for creating jobs in GitHub Workflows.
 */
export declare class WorkflowJobs {
    /**
     * Creates a pull request with the changes of a patch file.
     *
     * @returns Job
     */
    static pullRequestFromPatch(options: PullRequestFromPatchOptions): Job;
}
export interface PullRequestPatchSource {
    /**
     * The name of the workflow that will create the PR
     */
    readonly workflowName: string;
    /**
     * The id of the job that created the patch file
     */
    readonly jobId: string;
    /**
     * The name of the output that indicates if a patch has been created
     */
    readonly outputName: string;
    /**
     * The name of the artifact the patch is stored as.
     * @default ".repo.patch"
     */
    readonly patchFile?: string;
}
export interface PullRequestFromPatchOptions {
    /**
     * Information about the patch that is used to create the pull request.
     */
    readonly patch: PullRequestPatchSource;
    /**
     * The full title used to create the pull request.
     *
     * If PR titles are validated in this repo, the title should comply with the respective rules.
     */
    readonly pullRequestTitle: string;
    /**
     * Description added to the pull request.
     *
     * Providence information are automatically added.
     */
    readonly pullRequestDescription: string;
    /**
     * The git identity used to create the commit.
     */
    readonly gitIdentity: GitIdentity;
    /**
     * Add Signed-off-by line by the committer at the end of the commit log message.
     *
     * @default true
     */
    readonly signoff?: boolean;
    /**
     * The name of the job displayed on GitHub.
     * @default "Create Pull Request"
     */
    readonly jobName?: string;
    /**
     * The job credentials used to create the pull request.
     *
     * Provided credentials must have permissions to create a pull request on the repository.
     */
    readonly credentials: GithubCredentials;
    /**
     * Branch or tag name.
     * @default - the default branch is implicitly used
     */
    readonly ref?: string;
    /**
     * Github Runner selection labels
     * @default ["ubuntu-latest"]
     */
    readonly runsOn?: string[];
    /**
     * Labels to apply on the PR.
     *
     * @default - no labels.
     */
    readonly labels?: string[];
    /**
     * Assignees to add on the PR.
     *
     * @default - no assignees
     */
    readonly assignees?: string[];
}
